@@ -182,9 +182,11 @@ async function activate(
       // Identify the dashboard item associated with the widget
       const dashboard = dashboards.find(d => widget.item?.route === d.route);
 
-      // If the dashboard item doesn't exist in the new listing, close the pane.
-      if (!dashboard) {
-        widget.dispose();
+      // If the dashboard item doesn't exist in the new listing, or if the new
+      // url is inactive, mark the existing pane as such.
+      if (!dashboard || !input.urlInfo.isActive) {
+        widget.active = false;
+        widget.dashboardUrl = '';
         return;
       }
 
@@ -193,13 +195,6 @@ async function activate(
         widget.title.label = `${dashboard.label}`;
       }
 
-      // If the dashboard server is inactive, mark it as such.
-      if (!input.urlInfo.isActive) {
-        widget.dashboardUrl = '';
-        widget.active = false;
-        return;
-      }
-
       widget.dashboardUrl = input.urlInfo.effectiveUrl || input.urlInfo.url;
       widget.active = true;
     });
@@ -283,6 +278,10 @@ async function activate(
   // into the current session.
   let autoStartClient: boolean = false;
 
+  // Whether to hide the cluster manager for deployments that don't want to
+  // or are unable to use it.
+  let hideClusterManager: boolean = false;
+
   // Update the existing trackers and signals in light of a change to the
   // settings system. In particular, this reacts to a change in the setting
   // for auto-starting cluster client.
@@ -343,6 +342,11 @@ async function activate(
         // Determine whether to use the auto-starting client.
         autoStartClient = settings.get('autoStartClient').composite as boolean;
         updateTrackers();
+
+        //Determine whether to hide the cluster manager
+        hideClusterManager = settings.get('hideClusterManager')
+          .composite as boolean;
+        sidebar.clusterManager.setHidden(hideClusterManager);
       };
       onSettingsChanged();
       // React to a change in the settings.
